..
   Copyright DB InfraGO AG and contributors
   SPDX-License-Identifier: Apache-2.0


***********************************************
Welcome to the Capella ROS Tools documentation!
***********************************************

Overview
========

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :alt: Black

**Date**: |today| **Version**: |Version|

Capella ROS Tools is a command-line application written in Python, designed to facilitate the seamless integration of ROS2 and Capella MBSE tools. Key features include:

* Export Capella model elements as ROS2 message (.msg) files.
* Import ROS2 message (.msg) files as Capella model elements.
* Works with local and remote message files/Capella projects.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage
   howtos
   messages

.. toctree::
   :maxdepth: 3
   :caption: API reference:

   code/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
